@@ -14,7 +14,7 @@
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# Last edit by hansen on Mon Jan 19 12:50:17 2004
+# Last edit by hansen on Thu May  6 16:54:29 2004
 #
 #
 
@@ -81,6 +81,7 @@ set sopts_allowDebug $tkg_allowDebug
 set sopts_simActClock $tkg_simActClock
 set sopts_simUseActClock $tkg_simUseActClock
 set sopts_simInitScript $tkg_simInitScript
+set sopts_simRememberProbes $tkg_simRememberProbes
 set sopts_simLogFile ""
 set sopts_simDelayFile ""
 set sopts_simCustomDelay 0
@@ -96,6 +97,7 @@ proc tkg_saveOptions {} {
   global tkg_simStepSize tkg_simClockStepSize tkg_simClockOverStep tkg_simSortTraces
   global tkg_simActClock tkg_simUseActClock tkg_simDebugInterface tkg_contVerify
   global tkg_simInitScript tkg_simCustomDelay tkg_simDelayFile tkg_valuePopUpDelay
+  global tkg_simRememberProbes
 
   global tkg_instColor tkg_moduleColor tkg_modulePortColor tkg_frameColor 
   global tkg_commentColor tkg_hyperlinkColor tkg_wireColor tkg_busColor tkg_toolColor
@@ -139,6 +141,7 @@ proc tkg_saveOptions {} {
   puts $fd "#"
   puts $fd "# Simulator settings"
   puts $fd "#"
+  puts $fd "set tkg_simRememberProbes $tkg_simRememberProbes"
   puts $fd "set tkg_simSortTraces $tkg_simSortTraces"
   puts $fd "set tkg_simStepSize $tkg_simStepSize"
   puts $fd "set tkg_simClockStepSize $tkg_simClockStepSize"
@@ -253,6 +256,7 @@ proc tkg_optsGet {} {
 
   copyVar sopts_valuePopUpDelay tkg_valuePopUpDelay
   copyVar sopts_simSortTraces tkg_simSortTraces
+  copyVar sopts_simRememberProbes tkg_simRememberProbes
   copyVar sopts_simStepSize tkg_simStepSize
   copyVar sopts_simClockStepSize tkg_simClockStepSize
   copyVar sopts_simClockOverStep tkg_simClockOverStep
@@ -307,6 +311,7 @@ proc tkg_optsStore {} {
   checkCopyVar tkg_simClockStepSize sopts_simClockStepSize	1 1000000
   checkCopyVar tkg_simClockOverStep sopts_simClockOverStep	0 1000000
   copyVar tkg_simSortTraces sopts_simSortTraces	
+  copyVar tkg_simRememberProbes sopts_simRememberProbes	
   copyVar tkg_simDebugInterface sopts_simDebugInterface	
   copyVar tkg_contVerify sopts_contVerify	
   copyVar tkg_simActClock sopts_simActClock
@@ -652,7 +657,9 @@ proc tkg_eoSimBaseOpts {w} {
   label $w.t.vpopL -text "[m opt.vpopupdelay]:"
   entry $w.t.vpopE -width 5 -textvariable sopts_valuePopUpDelay
 
-  checkbutton $w.dosort -text "[m opt.sorttraces]" -variable sopts_simSortTraces
+  frame $w.opt
+  checkbutton $w.opt.dosort -text "[m opt.sorttraces]" -variable sopts_simSortTraces
+  checkbutton $w.opt.rememberp -text "[m opt.rememberprobes]" -variable sopts_simRememberProbes
 
   frame $w.i
   label $w.i.initL -text "[m opt.initscript]:"
@@ -678,7 +685,12 @@ proc tkg_eoSimBaseOpts {w} {
   grid $w.t.vpopE	-row 1 -column 1 -sticky w -padx 3 -pady 5 
 
   pack $w.t -anchor w
-  pack $w.dosort -padx 5 -pady 5 -anchor w 
+
+  pack $w.opt -anchor w 
+  pack $w.opt.dosort -padx 5 -pady 5 -anchor w -side left
+  pack $w.opt.rememberp -padx 5 -pady 5 -anchor w -side left
+
+
   pack $w.i -padx 5 -pady 5 -fill x -expand 1
   pack $w.i.initL -anchor w
   pack $w.i.browse -anchor w -fill x -padx 5 -pady 3 -side right
@@ -689,7 +701,8 @@ proc tkg_eoSimBaseOpts {w} {
   helpon $w.t.clkostepL [m ho.opt.ckover]
   helpon $w.t.vpopL [m ho.opt.vpopupdelay]
   helpon $w.i.initL [m ho.opt.init]
-  helpon $w.dosort [m ho.opt.sorttraces]
+  helpon $w.opt.dosort [m ho.opt.sorttraces]
+  helpon $w.opt.rememberp [m ho.opt.rememberprobes]
 }
 
 proc tkg_eoSimClock {w} {
