@@ -14,7 +14,7 @@
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# Last edit by hansen on Tue Mar  9 12:59:58 2004
+# Last edit by hansen on Tue May 25 09:10:18 2004
 #
 
 #Some common paper sizes (in mm):
@@ -378,21 +378,24 @@ proc tkg_prntStyleSel {w r} {
 }
 
 #
-# Print a file with default values
+# Print a file from the command line.
 #
-proc tkg_printWithDefaults {isFile name} {
+proc tkg_commandLinePrint {isFile name opts} {
   global pd_isfile pd_print pd_file pd_title pd_ok
   global tkg_currentFile tkg_displayFile
   global pd_file pd_paper pd_paperSizes pd_orient pd_style pd_select pd_selectList
   global pd_epsf pd_index pd_title pd_mergeSmall pd_duplexMode pd_inclib pd_graph pd_encoding
 
-
   set pd_title $tkg_displayFile
   set p [string last "/" $pd_file]
   if { $p >= 0 } { set pd_file [string range $pd_file [expr $p + 1] end]}
 
   scan $pd_paperSizes($pd_paper) "%s" curSize
 
+  foreach o $opts {
+    puts OPT=$o
+  }
+
   if {$isFile} {
     gat_print -file $name -paper $curSize -orient $pd_orient -style $pd_style -select $pd_select -modlist $pd_selectList -epsf $pd_epsf -index $pd_index -title $pd_title -merge $pd_mergeSmall -duplex $pd_duplexMode -graph $pd_graph -inclib $pd_inclib -encoding $pd_encoding
   } { 
