@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Dec  8 13:40:16 2003
+    Last edit by hansen on Wed May 26 12:46:23 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <string.h>
@@ -655,10 +655,16 @@ void Block_PSWrite(FILE *f,GModLayout *L,GCElement *g)
   
   if (g->ename && g->show_name) {
     char B[STRMAX];
+    int h;
+
+    if (XGate.tcl)
+      h = fontheight(XGate.stextF);
+    else
+      h = 8;
 
     sprintf(B,"(%s)",g->ename);
     PSDrawText(f,g->xpos + (g->u.block.gwidth / 2),
-	       g->ypos + (g->u.block.gheight / 2)+fontheight(XGate.stextF),8,
+	       g->ypos + (g->u.block.gheight / 2)+h,8,
 	       B,BetweenLeftAndRight | BetweenTopAndBottom);
   }
   if (g->u.block.BlockFunction) {
@@ -892,8 +898,12 @@ int block_setPortName(GCElement *g,GWire *w,EditState *es)
 void block_getwirexy(GWire *w,int d,int *x,int *y,int *p)
 {
   int h;
-  
-  h = fontheight(XGate.stextF);
+
+  if (XGate.tcl)
+    h = fontheight(XGate.stextF);
+  else
+    h = 8;
+
   switch (d) {
   case D_UP :
     *x = w->nodes->x;
