@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Dec  8 13:27:51 2003
+    Last edit by hansen on Fri May  7 13:19:09 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -795,6 +795,8 @@ void editstate_flushModules(EditState **es)
 {
   HashElem *E;
 
+  Circuit_clearProbes(XGate.circuit);
+
   while (*es)
     editstate_pop(es);
 
