@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Wed Feb 18 14:50:51 2004
+    Last edit by hansen on Tue Jun  8 11:54:02 2004
 ****************************************************************************/
 /*
     Postscript generator for tkgate.
@@ -186,8 +186,6 @@ PaperSize paperSizes[] = {
   {"Legal",	"legaltray",	INCH(8.5),	INCH(14)},
   {"Tabloid",	"11x17tray",	INCH(11),	INCH(17)},
   {"Executive",	"executivetray",INCH(7.5),	INCH(10)},
-  {"A6",	"a6tray",	MM(105),	MM(148)},
-  {"A5",	"a5tray",	MM(148),	MM(210)},
   {"A4",	"a4tray",	MM(210),	MM(297)},
   {"A3",	"a3tray",	MM(297),	MM(420)},
   {"A2",	"a2tray",	MM(420),	MM(594)},
@@ -415,6 +413,7 @@ void PSDrawText(FILE *f,int x,int y,int fsize,const char *text,int just)
 
 void GPrintOpt_init(GPrintOpt *PO)
 {
+  PO->po_title = 0;
   PO->po_cmd = 0;
   PO->po_file = 0;
   PO->po_paper = 0;
@@ -434,6 +433,31 @@ void GPrintOpt_init(GPrintOpt *PO)
   PO->po_encoding = 0;
 }
 
+/*
+ * Set up defaults for command line printing
+ */
+void GPrintOpt_clDefault(GPrintOpt *PO)
+{
+  PO->po_title = "";
+  PO->po_cmd = 0;
+  PO->po_file = 0;
+  PO->po_paper = "Letter";
+  PO->po_orient = "landscape";
+  PO->po_style = "partition";
+  PO->po_select = "all";
+  PO->po_modlist = "";
+  PO->po_epsf = "0";
+  PO->po_index = "0";
+  PO->po_graph = "0";
+  PO->po_4up = "1";
+  PO->po_isDuplex = "0";
+  PO->po_start = 0;
+  PO->po_end = 0;
+  PO->po_scale = 0;
+  PO->po_incLib = "0";
+  PO->po_encoding = 0;
+}
+
 GModLayout *new_GModLayout(GModuleDef *M)
 {
   GModLayout *L = (GModLayout *) ob_malloc(sizeof(GModLayout),"GModLayout");
@@ -487,8 +511,8 @@ int getUsedMods(NHash *H,GModLayout **L,GModuleDef *M,int incLib)
   int num = 0;
   HashElem *E;
 
-  if (NHash_find(H,(int)M)) return 0;
-  NHash_insert(H,(int)M,M);
+  if (NHash_find(H,(nkey_t)M)) return 0;
+  NHash_insert(H,(nkey_t)M,M);
 
   if (!M->is_lib || incLib)
     L[num++] = new_GModLayout(M);
@@ -645,7 +669,7 @@ GPrint *new_GPrint(GPrintOpt *PO)
       assert(P->p_mods);
 
       buf = strdup(PO->po_modlist);
-      for (T = strtok(buf," ");T;T = strtok(0," ")) {
+      for (T = strtok(buf," ,");T;T = strtok(0," ,")) {
 	char buf2[STRMAX];
 	GModuleDef *M = env_findModule(trimChars(buf2,T,"()+"));
 	if (M)
@@ -678,21 +702,23 @@ static void GPrint_pageSetup(GPrint *P)
   fprintf(P->p_f,"%%%%IncludeResource: font Hevetica-BoldOblique\n");
   fprintf(P->p_f,"%%%%IncludeResource: font Symbol\n");
 
-  fprintf(P->p_f,"%%%%BeginFeature: *PageSize %s\n",tray);
-  fprintf(P->p_f,"statusdict /%s known {\n",tray);
-  fprintf(P->p_f,"  statusdict begin\n");
-  fprintf(P->p_f,"    %s\n",tray);
-  fprintf(P->p_f,"  end\n");
-  fprintf(P->p_f,"} if\n");
-  fprintf(P->p_f,"%%%%EndFeature\n");
+  if (!P->p_isepsf) {
+    fprintf(P->p_f,"%%%%BeginFeature: *PageSize %s\n",tray);
+    fprintf(P->p_f,"statusdict /%s known {\n",tray);
+    fprintf(P->p_f,"  statusdict begin\n");
+    fprintf(P->p_f,"    %s\n",tray);
+    fprintf(P->p_f,"  end\n");
+    fprintf(P->p_f,"} if\n");
+    fprintf(P->p_f,"%%%%EndFeature\n");
 
-  fprintf(P->p_f,"%%%%BeginFeature: *DuplexMode %s\n",dup_mode);
-  fprintf(P->p_f,"statusdict /setduplexmode known {\n");
-  fprintf(P->p_f,"  statusdict begin\n");
-  fprintf(P->p_f,"    %s setduplexmode\n",dup_mode);
-  fprintf(P->p_f,"  end\n");
-  fprintf(P->p_f,"} if\n");
-  fprintf(P->p_f,"%%%%EndFeature\n");
+    fprintf(P->p_f,"%%%%BeginFeature: *DuplexMode %s\n",dup_mode);
+    fprintf(P->p_f,"statusdict /setduplexmode known {\n");
+    fprintf(P->p_f,"  statusdict begin\n");
+    fprintf(P->p_f,"    %s setduplexmode\n",dup_mode);
+    fprintf(P->p_f,"  end\n");
+    fprintf(P->p_f,"} if\n");
+    fprintf(P->p_f,"%%%%EndFeature\n");
+  }
 
   fprintf(P->p_f,"%%%%EndSetup\n");
 }
@@ -1241,19 +1267,19 @@ static HGNode *build_HGNodeGraph(GModuleDef *M,NHash *H)
 
   G = new_HGNode(M);
 
-  if (NHash_find(H,(unsigned)M)) {
+  if (NHash_find(H,(nkey_t)M)) {
     G->hg_expanded = 0;
   } else {
     G->hg_expanded = 1;
-    NHash_insert(H,(unsigned)M,M);
+    NHash_insert(H,(nkey_t)M,M);
     for (E = Hash_first(M->gates);E;E = Hash_next(M->gates,E)) {
       GCElement *g = (GCElement*) HashElem_obj(E);
       if (g->typeinfo->Code == BLOCK) {
 	GModuleDef *CM = env_findModule(g->u.block.BlockFunction);
 	HGNode *CG;
 
-	if (!NHash_find(LH,(unsigned)CM)) {
-	  NHash_insert(LH,(unsigned)CM,CM);
+	if (!NHash_find(LH,(nkey_t)CM)) {
+	  NHash_insert(LH,(nkey_t)CM,CM);
 	  CG = build_HGNodeGraph(CM,H);
 	  HGNode_addChild(G,CG);
 	}
@@ -1602,7 +1628,7 @@ void GPrint_hsortPages(GPrint *P)
 
   for (i = 0;i < P->p_numMods;i++) {
     L = P->p_mods[i];
-    NHash_insert(Mhash,(unsigned)L->l_mod,L);
+    NHash_insert(Mhash,(nkey_t)L->l_mod,L);
   }
 
 
@@ -1610,14 +1636,31 @@ void GPrint_hsortPages(GPrint *P)
   G = build_HGNodeGraph(XGate.circuit->root_mod,H);
   List_addToHead(&Q,G);
   while (List_numElems(&Q) > 0) {
+    GModuleDef *M;
     G = (HGNode*) List_popHead(&Q);
-    GModuleDef *M = G->hg_module;
+    M = G->hg_module;
 
     for (G = G->hg_children;G;G = G->hg_nextSibling) {
       List_addToTail(&Q,G);
     }
 
-    if ((L = (GModLayout*) NHash_find(Mhash,(unsigned)M))) {
+    if ((L = (GModLayout*) NHash_find(Mhash,(nkey_t)M))) {
+      if (N < P->p_numMods)
+	P->p_mods[N++] = L;
+      NHash_remove(Mhash,(nkey_t)M);
+    }
+  }
+
+  /*
+   * If there were fewer sorted modules, then in the original list, this means
+   * that we have unused modules.  In this case, we determine which modules are
+   * unused and add them to the end of the list.
+   */
+  if (N != P->p_numMods) {
+    HashElem *E;
+
+    for (E = Hash_first(Mhash);E;E = Hash_next(Mhash,E)) {
+      L = (GModLayout*) HashElem_obj(E);
       if (N < P->p_numMods)
 	P->p_mods[N++] = L;
     }
