@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Wed Dec 10 15:16:12 2003
+    Last edit by hansen on Fri May  7 12:56:25 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -895,6 +895,8 @@ void SimInterface_startUp(SimInterface *si)
 
   DoTcl("tkg_readSimInitScript");
 
+  Circuit_repostProbes(XGate.circuit);
+
   for (i = 0;i < XGate.circuit->numInitScripts;i++)
     DoTcl("gat_simScript \"%s\"",XGate.circuit->initScripts[i]);
 }
@@ -1089,6 +1091,7 @@ void SimInterface_begin(SimInterface *si)
  */
 void SimInterface_end(SimInterface *si)
 {
+  Circuit_extractProbes(XGate.circuit);
   si->active = 0;
   if (*si->simFileName)
     unlink(si->simFileName);
