@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Tue Mar  9 13:48:33 2004
+    Last edit by hansen on Tue Jun  8 13:09:56 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -100,13 +100,12 @@ int gat_new(ClientData _d,Tcl_Interp *tcl,int argc,const char *argv[])
 
   file = argv[1];
   topMod = argv[2];
+
   ob_touch(XGate.circuit);
   XGate.circuit->discardChanges = 0;
   XGate.circuit->useExtBars = 1;
   ClearModified();
-
-  Tcl_SetVar(XGate.tcl,"tkg_currentFile",file,TCL_GLOBAL_ONLY);
-  DoTcl("tkg_setDisplayFile %s",file);
+  Circuit_setCurrentFile(file);
 
   editstate_flushModules(es);
   M = env_findAdd(topMod,1);
@@ -154,11 +153,13 @@ int gat_load(ClientData _d,Tcl_Interp *tcl,int argc,const char *argv[])
   ob_touch(gw->parms->circuit);
   if (VerilogOpen(&gw->parms->circuit->es,name) < 0) {
     const char *curFile;
+
     if ((curFile = Tcl_GetVar(tcl,"tkg_currentFile",TCL_GLOBAL_ONLY)) && !*curFile) {
       Tcl_SetVar(XGate.tcl,"tkg_currentFile",name,TCL_GLOBAL_ONLY);
       DoTcl("tkg_setDisplayFile %s",name);
     } else
       message(1,msgLookup("err.badopen"),name);	/* Unable to open input file '%s' */
+
     if (old_mode == OM_ENABLED)
       ob_mode(old_mode);
     return TCL_OK;
@@ -166,9 +167,6 @@ int gat_load(ClientData _d,Tcl_Interp *tcl,int argc,const char *argv[])
 
   sel_clearDelta();
 
-  Tcl_SetVar(XGate.tcl,"tkg_currentFile",name,TCL_GLOBAL_ONLY);
-  DoTcl("tkg_setDisplayFile %s",name);
-
   ClearModified();
   FlagRedraw();
 
