@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Wed Feb 18 15:46:21 2004
+    Last edit by hansen on Mon Jun 14 10:25:04 2004
 ****************************************************************************/
 #include "tkgate.h"
 
@@ -24,7 +24,9 @@
 
 int do_panic_save = 1;
 int want_exit = 0;
+int is_verbose = 0;
 
+char *print_options = 0;
 char *print_file = 0;
 char *print_printer = 0;
 
@@ -195,6 +197,7 @@ void linkvars(Tcl_Interp *tcl)
   Tcl_LinkVar(tcl,"tkg_checkpointEnabled",(char*)&checkpointenabled,TCL_LINK_INT);
   Tcl_LinkVar(tcl,"tkg_wantCheckpoint",(char*)&wantCheckpoint,TCL_LINK_INT);
   Tcl_LinkVar(tcl,"tkg_simDebugInterface",(char*)&debugSimInterface,TCL_LINK_INT);
+  Tcl_LinkVar(tcl,"tkg_simRememberProbes",(char*)&XGate.circuit->c_rememberProbes,TCL_LINK_INT);
   Tcl_LinkVar(tcl,"tkg_baderMode",(char*)&baderp,TCL_LINK_INT);
   Tcl_LinkVar(tcl,"tkg_trekMode",(char*)&startrekp,TCL_LINK_INT);
   Tcl_LinkVar(tcl,"tkg_batMode",(char*)&batp,TCL_LINK_INT);
@@ -252,6 +255,7 @@ void localization_Setup(Tcl_Interp *tcl)
   FILE *f;
   int en_backup = 0;
   char *lang = 0;
+  int no_msg_count = 0;
 
   XGate.japaneseMode = 0;
   
@@ -318,7 +322,10 @@ void localization_Setup(Tcl_Interp *tcl)
       if (en_backup) {
 	if (!SHash_find(H,tag)) {
 	  SHash_insert(H,tag,ob_strdup(msg));
-	  logError(ERL_ERROR,"No localized string for symbol '%s'.  Using English value.",tag);
+	  if (is_verbose)
+	    logError(ERL_ERROR,"No localized string for symbol '%s'.  Using English value.",tag);
+	  else
+	    no_msg_count++;
 	}
       } else {
 	if (SHash_find(H,tag)) {
@@ -331,6 +338,11 @@ void localization_Setup(Tcl_Interp *tcl)
 
   fclose(f);
 
+  if (!is_verbose && no_msg_count > 0) {
+    logError(ERL_ERROR,"No localized strings for %d messages.  Use 'tkgate -v' for details.",no_msg_count);
+  }
+
+
   message_table = H;
 
   if (tcl)
@@ -397,58 +409,372 @@ void tkgate_signalSetup()
   }
 }
 
+Circuit *new_Circuit(int ob)
+{
+  Circuit *C;
+
+  if (ob)
+    C = (Circuit*) ob_malloc(sizeof(Circuit),"Circuit");
+  else
+    C = (Circuit*) malloc(sizeof(Circuit));
+  C->currentFile = 0;
+  C->fileVersion = 0;
+  C->mid_mod = new_GModuleDef("<module-interfaces>",1);
+  C->cut_buffer = 0;
+  C->mg_selection = 0;
+  C->rot = 0;
+  C->mode = MODE_MOVE;
+  C->numInitScripts = 0;
+  C->initScripts = 0;
+  C->zoom_factor = 1;
+  C->discardChanges = 0;
+  C->useExtBars = 1;
+  C->is_modified = 0;
+  C->es = new_EditState();
+  C->moduleTable = new_SHash();
+  C->c_rememberProbes = 1;
+  C->c_numProbes = 0;
+  C->c_probes = 0;
+
+  return C;
+}
+
+void delete_Circuit(Circuit *C)
+{
+}
+
+void Circuit_setTitle(const char *title)
+{
+}
+
+void Circuit_setCurrentFile(const char *name)
+{
+  ob_touch(XGate.circuit);
+  if (XGate.circuit->currentFile)
+    ob_free(XGate.circuit->currentFile);
+  XGate.circuit->currentFile = ob_strdup(name);
+
+  if (XGate.tcl) {
+    Tcl_SetVar(XGate.tcl,"tkg_currentFile",name,TCL_GLOBAL_ONLY);
+    DoTcl("tkg_setDisplayFile %s",name);
+  }
+}
+
+void Circuit_setCurrentFileVersion(const char *vnum)
+{
+  ob_touch(XGate.circuit);
+  if (XGate.circuit->fileVersion)
+    ob_free(XGate.circuit->fileVersion);
+  XGate.circuit->fileVersion = ob_strdup(vnum);
+
+  if (XGate.tcl)
+    Tcl_SetVar(XGate.tcl,"ecp_fileVersion",vnum,TCL_GLOBAL_ONLY);
+}
+
+/*****************************************************************************
+ *
+ * Clear any probes in the probe memory.
+ *
+ *****************************************************************************/
+void Circuit_clearProbes(Circuit *C)
+{
+  int i;
+
+  ob_touch(C);
+  C->c_numProbes = 0;
+  for (i = 0;i < C->c_numProbes;i++) {
+    ob_free(C->c_probes[i]);
+  }
+  if (C->c_probes)
+    ob_free(C->c_probes);
+  C->c_probes = 0;
+  C->c_numProbes = 0;
+}
+
+void Circuit_extractProbesAux(Circuit *C,GSimModule *M)
+{
+  HashElem *E;
+#define CPROBE_ALLOCSTEP	256
+
+  for (E = Hash_first(M->probes);E;E = Hash_next(M->probes,E)) {
+    GSimProbe *P = (GSimProbe*) HashElem_obj(E);
+
+    ob_touch(C);
+    if (C->c_numProbes == 0) {
+      C->c_probes = (char**) ob_malloc(sizeof(char*)*CPROBE_ALLOCSTEP,"char**");
+    } else if ((C->c_numProbes % CPROBE_ALLOCSTEP) == 0) {
+      C->c_probes = (char**) ob_realloc(C->c_probes,sizeof(char*)*(C->c_numProbes+CPROBE_ALLOCSTEP));
+    }
+    C->c_probes[C->c_numProbes++] = ob_strdup(P->name);
+  }
+
+  for (E = Hash_first(M->children);E;E = Hash_next(M->children,E)) {
+    GSimModule *cM = (GSimModule*) HashElem_obj(E);
+
+    Circuit_extractProbesAux(C,cM);
+  }
+}
+
+
+/*****************************************************************************
+ *
+ * Extract the set of probes already set and put them in the probe memory
+ *
+ *****************************************************************************/
+void Circuit_extractProbes(Circuit *C)
+{
+  Circuit_clearProbes(C);
+  if (!C->c_rememberProbes) return;
+  Circuit_extractProbesAux(C, C->simulator.sim_root);
+}
+
+void Circuit_repostProbes(Circuit *C)
+{
+  SimInterface *si = &XGate.circuit->simulator;
+  int i;
+
+  if (C->c_rememberProbes) {
+    for (i = 0;i < C->c_numProbes;i++) {
+      char *name = C->c_probes[i];
+      GSimModule *SM;
+      GWire *w;
+
+      if (SimInterface_lookupWire(si,name,&SM,&w) != 0)
+	continue;
+
+      if (SimInterface_probeExists(si,SM,name))
+	continue;
+
+      SimInterface_addDelProbe(si,SM,name,w,w->nodes,w->nodes->x,w->nodes->y);
+    }
+  }
+
+  Circuit_clearProbes(C);
+}
+
+
 /*****************************************************************************
  * Load the circuits on the command line only to check their integrety.
  *****************************************************************************/
 void doVerifyLoad()
 {
-    extern int VerilogErrorCount;
-    int i;
+  extern int VerilogErrorCount;
+  int i;
 
-    XGate.tcl = 0;
+  XGate.tcl = 0;
 
-    MakeHashTables();
-    icon_init();
-    init_gates();
+  MakeHashTables();
+  icon_init();
+  init_gates();
 
-    XGate.circuit = (Circuit*) malloc(sizeof(Circuit));
-    XGate.ed = (EditData*) malloc(sizeof(EditData));
-    XGate.errl = (ErrorList*) malloc(sizeof(ErrorList));
-    XGate.circuit->mode = MODE_MOVE;
-    XGate.circuit->es = new_EditState();
-    XGate.circuit->moduleTable = new_SHash();
-    XGate.circuit->mid_mod = new_GModuleDef("<module-interfaces>",1);
-    XGate.circuit->cut_buffer = 0;
-    XGate.circuit->mg_selection = 0;
-    XGate.circuit->rot = 0;
-    XGate.circuit->mode = MODE_MOVE;
-    XGate.circuit->numInitScripts = 0;
-    XGate.circuit->initScripts = 0;
-    XGate.circuit->zoom_factor = 1;
-    XGate.circuit->discardChanges = 0;
-    XGate.circuit->useExtBars = 1;
-    XGate.circuit->is_modified = 0;
-    localization_Setup(0);
+  XGate.ed = (EditData*) malloc(sizeof(EditData));
+  XGate.errl = (ErrorList*) malloc(sizeof(ErrorList));
 
-    for (i = 0;i < numLoads;i++) {
-      VerilogOpen(&XGate.circuit->es,loadList[i]);
+  XGate.circuit = new_Circuit(0);
 
-      /*
-       * We got an error reading a circuit file.
-       */
-      if (VerilogErrorCount > 0)
-	exit(1);
-    }
+  localization_Setup(0);
+
+  for (i = 0;i < numLoads;i++) {
+    VerilogOpen(&XGate.circuit->es,loadList[i]);
 
     /*
-     * We found inconsistencies in the file.
+     * We got an error reading a circuit file.
      */
-    if (verify_circuit() > 0)
-      exit(2);
+    if (VerilogErrorCount > 0)
+      exit(1);
+  }
 
-    exit(0);
- }
+  /*
+   * We found inconsistencies in the file.
+   */
+  if (verify_circuit() > 0)
+    exit(2);
 
+  exit(0);
+}
+
+/*
+ * Do defaults setup for command line printing.  We need to find out what the site
+ * name is and get the options from the user's preferences file.  We need to read
+ * the preferences file manually since we are not starting the tcl/tk interpreter.
+ */
+void commandLinePrintSetup(GPrintOpt *PO)
+{
+  FILE *f;
+  char buf[STRMAX];
+  char *p;
+
+  /*
+   * Get the default site name from the
+   */
+  sprintf(buf,"%s/sitename.txt",tkgate_homedir);
+  f = fopen(buf,"r");
+  if (f) {
+    if (fgets(buf,STRMAX,f)) {
+      p = strchr(buf,'\n');
+      if (p) *p = 0;
+      tkg_siteName = strdup(buf);
+    }
+    fclose(f);
+  }
+
+  GPrintOpt_clDefault(PO);
+
+  /*
+   * If we have a home directory, open the preferences file and read
+   * printing related defaults from it.
+   */
+  p = getenv("HOME");
+  if (p) {
+    extern PaperSize paperSizes[];
+
+    sprintf(buf,"%s/.tkgate-preferences",p);
+    f = fopen(buf,"r");
+    if (f) {
+      const char *lang = getenv("LANG");
+      char str[STRMAX];
+      int d;
+
+      while (fgets(buf,STRMAX,f)) {
+	if (sscanf(buf,"set tkg_siteName \"%[^\"]",str) == 1) {
+	  tkg_siteName = strdup(str);
+	} else if (sscanf(buf,"set tkg_printCommand \"%[^\"]",str) == 1) {
+	  PO->po_cmd = strdup(str);
+	} else if (sscanf(buf,"set tkg_printPgSizeA4 %d",&d) == 1) {
+	  if (strncmp(lang,"en",2) != 0)
+	    PO->po_paper = strdup(paperSizes[d].ps_size);
+	} else if (sscanf(buf,"set tkg_printPgSize %d",&d) == 1) {
+	  if (strncmp(lang,"en",2) == 0)
+	    PO->po_paper = strdup(paperSizes[d].ps_size);
+	} else if (sscanf(buf,"set tkg_printPgOrient %s",str) == 1) {
+	  PO->po_orient = strdup(str);
+	} else if (sscanf(buf,"set tkg_printStyle %s",str) == 1) {
+	  PO->po_style = strdup(str);
+	} else if (sscanf(buf,"set tkg_printDuplex %s",str) == 1) {
+	  PO->po_isDuplex = strdup(str);
+	} else if (sscanf(buf,"set tkg_printIndex %s",str) == 1) {
+	  PO->po_index = strdup(str);
+	} else if (sscanf(buf,"set tkg_printGraph %s",str) == 1) {
+	  PO->po_graph = strdup(str);
+	}
+      }
+      fclose(f);
+    }
+  }
+
+  if (!tkg_siteName)
+    tkg_siteName = strdup("CLP");
+
+}
+
+/*
+ * Set up for doing printing from the command line.
+ */
+void commandLinePrint()
+{
+  extern int VerilogErrorCount;
+  char *p;
+  int i;
+  GPrintOpt PO;
+  extern PaperSize paperSizes[];
+
+
+  XGate.tcl = 0;
+  MakeHashTables();
+  icon_init();
+  init_gates();
+  XGate.ed = (EditData*) malloc(sizeof(EditData));
+  XGate.errl = (ErrorList*) malloc(sizeof(ErrorList));
+  XGate.circuit = new_Circuit(0);
+  localization_Setup(0);
+
+  for (i = 0;i < numLoads;i++) {
+    VerilogOpen(&XGate.circuit->es,loadList[i]);
+
+    /*
+     * We got an error reading a circuit file.
+     */
+    if (VerilogErrorCount > 0)
+      exit(1);
+  }
+
+  /*
+   * Apply default options
+   */
+  commandLinePrintSetup(&PO);
+
+
+  if (print_file) {
+    PO.po_file = print_file;
+    PO.po_cmd = 0;
+  } else {
+    PO.po_cmd = print_printer;
+    PO.po_file = 0;
+  }
+
+  /*
+   * Apply printer options
+   */
+  for (p = strtok(print_options,":");p;p = strtok(0,":")) {
+    char name[STRMAX];
+    char sval[STRMAX];
+    int n;
+
+    if (!*p) continue;	/* Ignore empty options */
+
+    if (sscanf(p,"%[^=]=%s",name,sval) == 2) {
+    } else if (sscanf(p,"%[^=]",name) == 1) {
+      strcpy(sval,"1");
+    } else {
+      fprintf(stderr,"tkgate: Badly formatted print option '%s'\n",p);
+      fprintf(stderr,"  run 'tkgate -h' for help.\n");
+      exit(1);
+    }
+
+    n = strlen(name);
+    if (strncmp(name,"duplex",n) == 0) {
+      PO.po_isDuplex = strdup(sval);
+    } else if (strncmp(name,"epsf",n) == 0) {
+      PO.po_epsf = strdup(sval);
+    } else if (strncmp(name,"index",n) == 0) {
+      PO.po_index = strdup(sval);
+    } else if (strncmp(name,"hierarchy",n) == 0) {
+      PO.po_graph = strdup(sval);
+    } else if (strncmp(name,"paper",n) == 0) {
+      PO.po_paper = strdup(sval);
+    } else if (strncmp(name,"modules",n) == 0) {
+      PO.po_select = "sel";
+      PO.po_modlist = strdup(sval);
+    } else if (strncmp(name,"4up",n) == 0) {
+      PO.po_4up = strdup(sval);
+    } else {
+      fprintf(stderr,"tkgate: Unknown print option '%s'\n",name);
+      fprintf(stderr,"  run 'tkgate -h' for help.\n");
+      exit(1);
+    }
+  }
+
+
+  /*
+   * Check for valid paper size and convert to expected case if necessary.
+   */
+  for (i = 0;paperSizes[i].ps_size;i++)
+    if (strcasecmp(PO.po_paper,paperSizes[i].ps_size) == 0) {
+      PO.po_paper = paperSizes[i].ps_size;
+      break;
+    }
+  if (!paperSizes[i].ps_size) {
+      fprintf(stderr,"tkgate: Unknown paper size '%s'\n",PO.po_paper);
+      exit(1);
+  }
+
+
+  ob_begin_frame("Print");
+  GPrintOpt_print(&PO);
+  ob_end_frame();
+
+  exit(0);
+}
 
 void usage()
 {
@@ -463,6 +789,19 @@ void usage()
   fprintf(stderr,"    -L lang    Specify language (if configured).\n");
   fprintf(stderr,"    -p file    Print to a file.\n");
   fprintf(stderr,"    -P prn     Output to a printer.\n");
+  fprintf(stderr,"    -O opts    Printer options.\n");
+  fprintf(stderr,"\n");
+  fprintf(stderr,"  Printer options are specified as a colon separated list of\n");
+  fprintf(stderr,"  the following items (identifiers can be abreviated):\n");
+  fprintf(stderr,"\n");
+  fprintf(stderr,"    epsf=bool      Use encapsulated Postscript format\n");
+  fprintf(stderr,"    duplex=bool    Use duplex printing\n");
+  fprintf(stderr,"    index=bool     Include index\n");
+  fprintf(stderr,"    hier=bool      Include hierarchy graph\n");
+  fprintf(stderr,"    paper=type     Use specified paper type\n");
+  fprintf(stderr,"    4up=bool       Do 4-up printing of small modules\n");
+  fprintf(stderr,"    modules=list   List of modules to print (comma separated)\n");
+  fprintf(stderr,"\n");
   exit(1);
 }
 
@@ -481,8 +820,11 @@ void parse_options(int argc,char *argv[])
   libLoadList = (char**) calloc(argc,sizeof(char*));
 
   while (argc > 0) {
-    while ((c = getopt(argc,argv,"VAhdxqsX:l:L:p:P:")) != EOF) {
+    while ((c = getopt(argc,argv,"vVAhdxqsX:l:L:p:P:O:")) != EOF) {
       switch (c) {
+      case 'v' :
+	is_verbose = 1;
+	break;
       case 'V' :
 	verify_only = 1;
 	break;
@@ -493,6 +835,14 @@ void parse_options(int argc,char *argv[])
 	start_sim = 1;
 	sim_script = optarg;
 	break;
+      case 'O' :
+	if (print_options) {
+	  print_options = realloc(print_options,strlen(print_options)+strlen(optarg)+2);
+	  strcat(print_options,":");
+	  strcat(print_options,optarg);
+	} else
+	  print_options = strdup(optarg);
+	break;
       case 'p' :
 	print_file = optarg;
 	break;
@@ -550,6 +900,8 @@ void parse_options(int argc,char *argv[])
 
   if (verify_only)
     doVerifyLoad();
+  if (print_file || print_printer)
+    commandLinePrint();
 }
 
 /*
@@ -663,23 +1015,6 @@ void TkGate_init(Tcl_Interp *tcl)
   if (noviceMode && !did_load)
     DoTcl("tkg_loadNoviceCircuit");
 
-  /*
-   * If a print file has been specified.  Print the file and exit tkgate.
-   */
-  if (print_file) {
-    DoTcl("tkg_printWithDefaults 1 %s",print_file);
-    exit(0);
-  }
-
-  /*
-   * If a printer has been specified.  Print to specified printer and
-   * exit tkgate.
-   */
-  if (print_printer) {
-    DoTcl("tkg_printWithDefaults 0 {lpr -P%s}",print_printer);
-    exit(0);
-  }
-
   bader_check();
   tkgate_signalSetup();			/* set traps on signals */
 }
