@@ -209,6 +209,9 @@ struct tkggatwin_str {
  */
 typedef struct circuit_str Circuit;
 struct circuit_str {
+  char		*currentFile;	/* Current file name */
+  char		*fileVersion;	/* Version of current file */
+
   GCutBuffer	*cut_buffer;	/* Buffer for cut/paste operations */
   GSelection	*mg_selection;	/* The current multi-gate selection */
   
@@ -224,6 +227,10 @@ struct circuit_str {
   int		numInitScripts;	/* Number of simulation initialization scripts */
   char		**initScripts;	/* Simulation initialization scripts */
 
+  int		c_rememberProbes;
+  int		c_numProbes;	/* Number of remembered probes */
+  char		**c_probes;	/* Remembered probes */
+
   GCElement *select;		/* Current single-gate selection */
   GCElement *last;		/* Last selected gate */
   GWire *wsel;			/* Selected wire */
@@ -566,6 +573,15 @@ void SetErrorPosition(int,int);
 
 void gateCleanUp();
 
+Circuit *new_Circuit(int);
+void delete_Circuit(Circuit *);
+void Circuit_clearProbes(Circuit*);
+void Circuit_extractProbes(Circuit*);
+void Circuit_repostProbes(Circuit*);
+void Circuit_setTitle(const char*);
+void Circuit_setCurrentFile(const char*);
+void Circuit_setCurrentFileVersion(const char*);
+
 extern XGateParams XGate;
 
 extern char *BODYFONT; 
