@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Thu Feb  5 11:06:44 2004
+    Last edit by hansen on Thu May  6 15:05:20 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -1214,7 +1214,6 @@ void configureMainWindow(Tcl_Interp *tcl)
   Tk_Window root = Tk_MainWindow(tcl);
   Tk_MakeWindowExist(root);
 
-  XGate.circuit = (Circuit*) ob_malloc(sizeof(Circuit),"Circuit");
   XGate.ed = (EditData*) ob_malloc(sizeof(EditData),"EditData");
   XGate.errl = (ErrorList*) ob_malloc(sizeof(ErrorList),"ErrorList");
 
@@ -1225,17 +1224,10 @@ void configureMainWindow(Tcl_Interp *tcl)
   XGate.CM = DefaultColormapOfScreen(XGate.S);
   XGate.ScopeW = None;
   XGate.rdb = XrmGetDatabase(XGate.D);
-  XGate.circuit->mid_mod = new_GModuleDef("<module-interfaces>",1);
-  XGate.circuit->cut_buffer = 0;
-  XGate.circuit->mg_selection = 0;
-  XGate.circuit->rot = 0;
-  XGate.circuit->mode = MODE_MOVE;
-  XGate.circuit->numInitScripts = 0;
-  XGate.circuit->initScripts = 0;
-  XGate.circuit->zoom_factor = 1;
-  XGate.circuit->discardChanges = 0;
-  XGate.circuit->useExtBars = 1;
-  XGate.circuit->is_modified = 0;
+
+
+  XGate.circuit = new_Circuit(1);
+
   XGate.ed->mark_vis = 0;
   XGate.ed->mark_posted = 0;
   XGate.ed->major_mode = MM_EDIT;
@@ -1248,9 +1240,6 @@ void configureMainWindow(Tcl_Interp *tcl)
   XGate.ErrorMarkTimeout = 0;
 
   XGate_clearSelection();
-
-  XGate.circuit->moduleTable = new_SHash();
-
   XGate_clearSelection();
 
   SimInterface_init(&XGate.circuit->simulator);
