@@ -208,7 +208,7 @@ int VerilogBasicGateParmList(FILE *f,GCElement *g)
       if (w->net->signame)
 	fprintf(f,"(%s%s)",inv,w->net->signame);
       else
-	fprintf(f,"(%sw%x)",inv,(unsigned)w->net);
+	fprintf(f,"(%sw%x)",inv,(size_t)w->net);
     } 
   }
   fprintf(f,");");
@@ -330,7 +330,7 @@ static void VerilogSaveOneNet(FILE *f,GNet *n)
   if (n->signame)
     fprintf(f,"%s;    ",n->signame);
   else
-    fprintf(f,"w%x;    ",(unsigned)n);
+    fprintf(f,"w%x;    ",(size_t)n);
 
   fprintf(f,"//:");
   if (!n->show_name)
@@ -681,6 +681,8 @@ int VerilogOpen(EditState **es,const char *name)
     return -1;
   }
 
+  Circuit_setCurrentFile(name);
+
   editstate_flushModules(es);
   topModule = 0;
 
@@ -814,8 +816,7 @@ void VerCheckVersion(const char *version)
   ParseVersion(VERSIONS[0].name, &V);
   cur.gate_ver = V;
 
-  if (XGate.tcl)
-    Tcl_SetVar(XGate.tcl,"ecp_fileVersion",version,TCL_GLOBAL_ONLY);
+  Circuit_setCurrentFileVersion(version);
 
   if (ParseVersion(version, &V) < 0) {
     message(1,msgLookup("err.badversion"));
@@ -972,9 +973,9 @@ void VerEndModule()
     if (w1 == w2) continue;
 
     if (!w1->gate && !w2->gate) {
-      NHash_insert(bad_wires,(int)w2,w2);
-      NHash_insert(bad_wires,(int)w1,w1);
-      NHash_insert(bad_nets,(int)w1->net,w1->net);
+      NHash_insert(bad_wires,(nkey_t)w2,w2);
+      NHash_insert(bad_wires,(nkey_t)w1,w1);
+      NHash_insert(bad_nets,(nkey_t)w1->net,w1->net);
     }
   }
 
